# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""Astrophysical population models."""
from .spatial import *
from .velocity import *
from .simulate import *
